@@ -25,7 +25,7 @@ def request(api, params):
         raise Exception(repDic["msg"])
     if repDic["data"]["err"] != 0:
         raise Exception(repDic["data"]["msg"])
-    return repDic
+    return repDic["data"]["res"]
 
 """
 文件上传
